#!/bin/sh

# openconnect will call this script with the follow command-line
# arguments, which are needed to populate the contents of the
# HIP report:
#
#   --cookie: a URL-encoded string, as output by openconnect
#             --authenticate --protocol=gp, which includes parameters
#             from the /ssl-vpn/login.esp response
#
#   --client-ip: IPv4 address allocated by the GlobalProtect VPN for
#                this client (included in /ssl-vpn/getconfig.esp
#                response)
#
#   --md5: The md5 digest to encode into this HIP report. I'm not sure
#          exactly what this is the md5 digest *of*, but all that
#          really matters is that the value in the HIP report
#          submission should match the value in the HIP report check.

# Today's date
TODAY_DAY=$(date +%-d)
TODAY_MONTH=$(date +%-m)
TODAY_YEAR=$(date +%Y)

# Read command line arguments into variables

COOKIE=
IP=
MD5=

while [ "$1" ]; do
    if [ "$1" = "--cookie" ];    then shift; COOKIE="$1"; fi
    if [ "$1" = "--client-ip" ]; then shift; IP="$1"; fi
    if [ "$1" = "--md5" ];       then shift; MD5="$1"; fi
    shift
done

if [ -z "$COOKIE" -o -z "$IP" -o -z "$MD5" ]; then
    echo "Parameters --cookie, --computer, --client-ip, and --md5 are required" >&2
    exit 1;
fi

# Extract username and domain and computer from cookie
USER=$(echo "$COOKIE" | sed -rn 's/(.+&|^)user=([^&]+)(&.+|$)/\2/p')
DOMAIN=$(echo "$COOKIE" | sed -rn 's/(.+&|^)domain=([^&]+)(&.+|$)/\2/p')
COMPUTER=$(echo "$COOKIE" | sed -rn 's/(.+&|^)computer=([^&]+)(&.+|$)/\2/p')

# Timestamp in the format expected by GlobalProtect server
NOW=$(date +'%m/%d/%Y %H:%M:%S')

# This value may need to be extracted from the official HIP report, if a made-up value is not accepted.
HOSTID="deadbeef-dead-beef-dead-beefdeadbeef"

cat <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<hip-report>
<md5-sum>$MD5</md5-sum>
	<user-name>$USER</user-name>
	<domain>$DOMAIN</domain>
	<host-name>$COMPUTER</host-name>
	<host-id>$HOSTID</host-id>
	<ip-address>$IP</ip-address>
	<ipv6-address></ipv6-address>
	<generate-time>$NOW</generate-time>
	<hip-report-version>4</hip-report-version>
	<categories>
		<entry name="host-info">
			<client-version>5.2.5-66</client-version>
			<os>Microsoft Windows 10 Home , 64-bit</os>
			<os-vendor>Microsoft</os-vendor>
			<domain>$DOMAIN.internal</domain>
			<host-name>$COMPUTER</host-name>
			<host-id>$HOSTID</host-id>
			<network-interface>
				<entry name="{7C5701F8-FD9A-408E-B440-9B6946E315EE}">
					<description>PANGP Virtual Ethernet Adapter</description>
					<mac-address>02-50-41-00-00-01</mac-address>
					<ip-address>
						<entry name="$IP"/>
					</ip-address>
				</entry>
				<entry name="{2213EE2D-5836-4722-8B58-815AEC4876D2}">
					<description>Realtek PCIe GbE Family Controller</description>
					<mac-address>04-42-1A-D2-D5-C2</mac-address>
					<ip-address>
						<entry name="169.254.139.76"/>
					</ip-address>
					<ipv6-address>
						<entry name="fe80::4d0a:4691:8929:8b4c"/>
					</ipv6-address>
				</entry>
				<entry name="{8ADDD006-4D2A-4A06-9497-1663E507C4D4}">
					<description>VirtualBox Host-Only Ethernet Adapter</description>
					<mac-address>0A-00-27-00-00-0A</mac-address>
					<ip-address>
						<entry name="192.168.56.1"/>
					</ip-address>
					<ipv6-address>
						<entry name="fe80::9888:d32a:1fd5:f06a"/>
					</ipv6-address>
				</entry>
				<entry name="{0271B578-3DC6-42CB-ABDF-5C782939EF54}">
					<description>Microsoft Wi-Fi Direct Virtual Adapter</description>
					<mac-address>92-E8-68-5E-49-2F</mac-address>
					<ip-address>
						<entry name="169.254.106.222"/>
					</ip-address>
					<ipv6-address>
						<entry name="fe80::4cc7:a505:f3af:6ade"/>
					</ipv6-address>
				</entry>
				<entry name="{1C02A4B4-C418-49C2-A644-00DDE1F344FA}">
					<description>Microsoft Wi-Fi Direct Virtual Adapter #3</description>
					<mac-address>92-E8-68-5E-49-3F</mac-address>
					<ip-address>
						<entry name="192.168.137.1"/>
					</ip-address>
					<ipv6-address>
						<entry name="fe80::8972:6bcd:4c4f:32dc"/>
					</ipv6-address>
				</entry>
				<entry name="{F85384D2-0C56-47AD-AAF5-8D41FDFF7DFC}">
					<description>MediaTek Wi-Fi 6 MT7921 Wireless LAN Card</description>
					<mac-address>90-E8-68-5E-49-0F</mac-address>
					<ip-address>
						<entry name="192.168.1.15"/>
					</ip-address>
					<ipv6-address>
						<entry name="fe80::8136:ffa6:a7d9:b436"/>
					</ipv6-address>
				</entry>
				<entry name="{B13BAA58-12DB-47EE-B05D-E1D470674BA5}">
					<description>Bluetooth Device (Personal Area Network)</description>
					<mac-address>90-E8-68-5E-49-0E</mac-address>
					<ip-address>
						<entry name="169.254.63.61"/>
					</ip-address>
					<ipv6-address>
						<entry name="fe80::9f6:da08:d1f7:3f3d"/>
					</ipv6-address>
				</entry>
				<entry name="{8B0005E4-CCA3-11EC-A89B-806E6F6E6963}">
					<description>Software Loopback Interface 1</description>
					<mac-address></mac-address>
					<ip-address>
						<entry name="127.0.0.1"/>
					</ip-address>
					<ipv6-address>
						<entry name="::1"/>
					</ipv6-address>
				</entry>
			</network-interface>
		</entry>
		<entry name="anti-malware">
			<list>
				<entry>
					<ProductInfo>
						<Prod vendor="Microsoft Corporation" name="Windows Defender" version="4.18.2203.5" defver="1.363.1534.0" engver="1.1.19200.5" datemon="$TODAY_MONTH" dateday="$TODAY_DAY" dateyear="$TODAY_YEAR" prodType="3" osType="1"/>
						<real-time-protection>yes</real-time-protection>
						<last-full-scan-time>n/a</last-full-scan-time>
					</ProductInfo>
				</entry>
			</list>
		</entry>
	</categories>
</hip-report>
EOF
